API Reference
~~~~~~~~~~~~~

.. automodule:: argh
   :members:

.. automodule:: argh.decorators
   :members:

.. automodule:: argh.assembling
   :members:

.. automodule:: argh.dispatching
   :members:

.. automodule:: argh.interaction
   :members:

.. automodule:: argh.completion
   :members:

.. automodule:: argh.helpers
   :members:

.. automodule:: argh.exceptions
   :members:

.. automodule:: argh.io
   :members:

.. automodule:: argh.utils
   :members:

.. automodule:: argh.constants
   :members:
